Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| LILAS COMERCIO DE PERFUMARIAS LTDA EPP
CNPJ: 12.958.035/0009-74 Inscrição Estadual: 1090394249
AV FERNANDO FERRARI, 1483, NOSSA SENHORA DE LOURDES, SANTA MARIA, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 28831 Série: 1 Data de Emissão: 15/10/2019 18:59:46
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 1012 9580 3500 0974 6500 1000 0288 3119 1747 1901
Protocolo de Autorização: 143191419905513
CONSUMIDOR
CPF: 044.272.479-97 - NAO INFORMADO
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
74697 | NSPA SAB LIQ MAOS CVR 400ml | 1 | pc | 47,9 | 47,90
72051 | NSPA CREM HID DES MAOS CVR 75g | 1 | pc | 37,9 | 37,90
Valor total R$ | 68,64
Valor descontos R$ | 17,16
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:45